# Changelog

## [v0.1](https://github.com/scientific-python/yaml2ics/tree/v0.1)

[Full Changelog](https://github.com/scientific-python/yaml2ics/compare/v0.1rc3...v0.1)

**Closed issues:**

- Release please [\#42](https://github.com/scientific-python/yaml2ics/issues/42)

**Merged pull requests:**

- Announce Python 3.11 support [\#43](https://github.com/scientific-python/yaml2ics/pull/43) ([jarrodmillman](https://github.com/jarrodmillman))
- Add ability to specify custom ICS [\#41](https://github.com/scientific-python/yaml2ics/pull/41) ([stefanv](https://github.com/stefanv))
- Fix markdown syntax [\#40](https://github.com/scientific-python/yaml2ics/pull/40) ([jarrodmillman](https://github.com/jarrodmillman))
- Add test and coverage badges [\#39](https://github.com/scientific-python/yaml2ics/pull/39) ([jarrodmillman](https://github.com/jarrodmillman))
- Update install and release notes [\#38](https://github.com/scientific-python/yaml2ics/pull/38) ([jarrodmillman](https://github.com/jarrodmillman))
- Measure test coverage [\#37](https://github.com/scientific-python/yaml2ics/pull/37) ([jarrodmillman](https://github.com/jarrodmillman))
- Add classifiers [\#36](https://github.com/scientific-python/yaml2ics/pull/36) ([jarrodmillman](https://github.com/jarrodmillman))
- Lint toml [\#35](https://github.com/scientific-python/yaml2ics/pull/35) ([jarrodmillman](https://github.com/jarrodmillman))
- Fix linting [\#34](https://github.com/scientific-python/yaml2ics/pull/34) ([jarrodmillman](https://github.com/jarrodmillman))

## [v0.1rc3](https://github.com/scientific-python/yaml2ics/tree/v0.1rc3) (2022-08-21)

[Full Changelog](https://github.com/scientific-python/yaml2ics/compare/v0.1rc2...v0.1rc3)

**Merged pull requests:**

- Use ics pypi pre-release [\#33](https://github.com/scientific-python/yaml2ics/pull/33) ([jarrodmillman](https://github.com/jarrodmillman))

## [v0.1rc2](https://github.com/scientific-python/yaml2ics/tree/v0.1rc2) (2022-08-12)

[Full Changelog](https://github.com/scientific-python/yaml2ics/compare/v0.1rc1...v0.1rc2)

**Closed issues:**

- Add the possibility to skip dates for recurring events [\#23](https://github.com/scientific-python/yaml2ics/issues/23)

**Merged pull requests:**

- Add changelog [\#32](https://github.com/scientific-python/yaml2ics/pull/32) ([jarrodmillman](https://github.com/jarrodmillman))
- Add release process notes [\#31](https://github.com/scientific-python/yaml2ics/pull/31) ([jarrodmillman](https://github.com/jarrodmillman))
- Specify lower bounds on dependencies [\#30](https://github.com/scientific-python/yaml2ics/pull/30) ([jarrodmillman](https://github.com/jarrodmillman))
- Improve CI testing [\#29](https://github.com/scientific-python/yaml2ics/pull/29) ([jarrodmillman](https://github.com/jarrodmillman))
- Run linter [\#28](https://github.com/scientific-python/yaml2ics/pull/28) ([jarrodmillman](https://github.com/jarrodmillman))
- Update precommit hooks [\#27](https://github.com/scientific-python/yaml2ics/pull/27) ([jarrodmillman](https://github.com/jarrodmillman))
- Update GH actions [\#26](https://github.com/scientific-python/yaml2ics/pull/26) ([jarrodmillman](https://github.com/jarrodmillman))
- Simplify install [\#25](https://github.com/scientific-python/yaml2ics/pull/25) ([jarrodmillman](https://github.com/jarrodmillman))
- Add the possibility to skip dates for recurring events [\#24](https://github.com/scientific-python/yaml2ics/pull/24) ([itrich](https://github.com/itrich))
- yaml2ics: Allow a "timezone" option within each event. [\#22](https://github.com/scientific-python/yaml2ics/pull/22) ([rkdarst](https://github.com/rkdarst))

## [v0.1rc1](https://github.com/scientific-python/yaml2ics/tree/v0.1rc1) (2022-03-02)

[Full Changelog](https://github.com/scientific-python/yaml2ics/compare/v0.0...v0.1rc1)

**Implemented enhancements:**

- Add X-WR-CALNAME in extras on top of NAME [\#16](https://github.com/scientific-python/yaml2ics/pull/16) ([tupui](https://github.com/tupui))

**Closed issues:**

- Build system [\#20](https://github.com/scientific-python/yaml2ics/issues/20)
- Make installable? [\#17](https://github.com/scientific-python/yaml2ics/issues/17)
- Intervals between events is not respected [\#14](https://github.com/scientific-python/yaml2ics/issues/14)
- Updating to ICS 0.8 [\#3](https://github.com/scientific-python/yaml2ics/issues/3)
- Roadmap of this project [\#1](https://github.com/scientific-python/yaml2ics/issues/1)

**Merged pull requests:**

- Package library [\#19](https://github.com/scientific-python/yaml2ics/pull/19) ([tupui](https://github.com/tupui))
- Add missing interval to RRULE [\#15](https://github.com/scientific-python/yaml2ics/pull/15) ([stefanv](https://github.com/stefanv))
- Add calendar name field [\#13](https://github.com/scientific-python/yaml2ics/pull/13) ([stefanv](https://github.com/stefanv))
- Update black [\#12](https://github.com/scientific-python/yaml2ics/pull/12) ([stefanv](https://github.com/stefanv))
- Add 'include' to metadata to include other files. [\#11](https://github.com/scientific-python/yaml2ics/pull/11) ([rkdarst](https://github.com/rkdarst))
- Add Github Actions to run tests [\#10](https://github.com/scientific-python/yaml2ics/pull/10) ([rkdarst](https://github.com/rkdarst))
- Fix several tests [\#9](https://github.com/scientific-python/yaml2ics/pull/9) ([rkdarst](https://github.com/rkdarst))
- Add per-calendar default timezone \(in meta header\) [\#8](https://github.com/scientific-python/yaml2ics/pull/8) ([rkdarst](https://github.com/rkdarst))
- Don't set end=None for recurring events [\#7](https://github.com/scientific-python/yaml2ics/pull/7) ([rkdarst](https://github.com/rkdarst))
- Fix rrule creation: use name= and value= for more correct syntax. [\#6](https://github.com/scientific-python/yaml2ics/pull/6) ([rkdarst](https://github.com/rkdarst))
- Print error messages to stderr, not stdout [\#5](https://github.com/scientific-python/yaml2ics/pull/5) ([rkdarst](https://github.com/rkdarst))
- Port yaml2ics to ics 0.8.0 [\#4](https://github.com/scientific-python/yaml2ics/pull/4) ([rkdarst](https://github.com/rkdarst))
- requirements: Add PyYAML [\#2](https://github.com/scientific-python/yaml2ics/pull/2) ([rkdarst](https://github.com/rkdarst))

\* _This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)_
